@@ -37,7 +37,9 @@ from ._constants import (
     _DEFAULT_MANDATORY_REFRESH_TIMEOUT,
     _DEFAULT_STS_TIMEOUT,
     _DEFAULT_RESOURCE_TYPE,
+    _PRESETENDPOINT_RESOURCE_TYPE,
     DEFAULT_TIMEOUT,
+    _BOT_RESOURCE_TYPE,
 )
 from ._streaming import Stream
 
@@ -137,16 +139,22 @@ class Ark(SyncAPIClient):
         self.files = resources.Files(self)
         # self.classification = resources.Classification(self)
 
-    def _get_endpoint_sts_token(self, endpoint_id: str):
+    def _get_endpoint_sts_token(self, endpoint_id: str, project_name: str = None):
         if self._sts_token_manager is None:
             if self.ak is None or self.sk is None:
-                raise ArkAPIError("must set ak and sk before get endpoint token.")
-            self._sts_token_manager = StsTokenManager(self.ak, self.sk, self.region)
-        return self._sts_token_manager.get(endpoint_id)
+                raise ArkAPIError(
+                    "must set ak and sk before get endpoint token.")
+            self._sts_token_manager = StsTokenManager(
+                self.ak, self.sk, self.region)
+        resource_type: str = self.get_resource_type_by_endpoint_id(endpoint_id)
+        if resource_type == _PRESETENDPOINT_RESOURCE_TYPE and (project_name is None or project_name.strip() == ""):
+            raise ArkAPIError(
+                "must set project_name when get preset endpoint token.")
+        return self._sts_token_manager.get(endpoint_id, resource_type=resource_type, project_name=project_name)
 
     def _get_endpoint_certificate(
         self, endpoint_id: str
-    ) -> Tuple[key_agreement_client, str, str, float]:
+    ) -> key_agreement_client:
         if self._certificate_manager is None:
             cert_path = os.environ.get("E2E_CERTIFICATE_PATH")
             if (
@@ -166,8 +174,10 @@ class Ark(SyncAPIClient):
     def _get_bot_sts_token(self, bot_id: str):
         if self._sts_token_manager is None:
             if self.ak is None or self.sk is None:
-                raise ArkAPIError("must set ak and sk before get endpoint token.")
-            self._sts_token_manager = StsTokenManager(self.ak, self.sk, self.region)
+                raise ArkAPIError(
+                    "must set ak and sk before get endpoint token.")
+            self._sts_token_manager = StsTokenManager(
+                self.ak, self.sk, self.region)
         return self._sts_token_manager.get(bot_id, resource_type="bot")
 
     @property
@@ -179,6 +189,16 @@ class Ark(SyncAPIClient):
         with self.model_breaker_lock:
             return self.model_breaker_map[model_name]
 
+    def get_resource_type_by_endpoint_id(self, endpoint_id: str) -> str:
+        if endpoint_id.startswith("ep-m-"):
+            return _PRESETENDPOINT_RESOURCE_TYPE
+        if endpoint_id.startswith("ep-"):
+            return _DEFAULT_RESOURCE_TYPE
+        if endpoint_id.startswith("bot-"):
+            return _BOT_RESOURCE_TYPE
+        # for model id, default to preset endpoint
+        return _PRESETENDPOINT_RESOURCE_TYPE
+
 
 class AsyncArk(AsyncAPIClient):
     beta: beta.AsyncBeta
@@ -273,20 +293,24 @@ class AsyncArk(AsyncAPIClient):
     def _get_endpoint_sts_token(self, endpoint_id: str):
         if self._sts_token_manager is None:
             if self.ak is None or self.sk is None:
-                raise ArkAPIError("must set ak and sk before get endpoint token.")
-            self._sts_token_manager = StsTokenManager(self.ak, self.sk, self.region)
+                raise ArkAPIError(
+                    "must set ak and sk before get endpoint token.")
+            self._sts_token_manager = StsTokenManager(
+                self.ak, self.sk, self.region)
         return self._sts_token_manager.get(endpoint_id)
 
     def _get_bot_sts_token(self, bot_id: str):
         if self._sts_token_manager is None:
             if self.ak is None or self.sk is None:
-                raise ArkAPIError("must set ak and sk before get endpoint token.")
-            self._sts_token_manager = StsTokenManager(self.ak, self.sk, self.region)
+                raise ArkAPIError(
+                    "must set ak and sk before get endpoint token.")
+            self._sts_token_manager = StsTokenManager(
+                self.ak, self.sk, self.region)
         return self._sts_token_manager.get(bot_id, resource_type="bot")
 
     def _get_endpoint_certificate(
         self, endpoint_id: str
-    ) -> Tuple[key_agreement_client, str, str, float]:
+    ) -> key_agreement_client:
         if self._certificate_manager is None:
             cert_path = os.environ.get("E2E_CERTIFICATE_PATH")
             if (
@@ -350,6 +374,7 @@ class StsTokenManager(object):
         ttl: int = _DEFAULT_STS_TIMEOUT,
         is_mandatory: bool = False,
         resource_type: str = _DEFAULT_RESOURCE_TYPE,
+        project_name: str = None,
     ):
         if ttl < self._advisory_refresh_timeout * 2:
             raise ArkAPIError(
@@ -360,7 +385,7 @@ class StsTokenManager(object):
 
         try:
             api_key, expired_time = self._load_api_key(
-                ep, ttl, resource_type=resource_type
+                ep, ttl, resource_type=resource_type, project_name=project_name
             )
             self._endpoint_sts_tokens[ep] = (api_key, expired_time)
         except ApiException as e:
@@ -369,7 +394,7 @@ class StsTokenManager(object):
             else:
                 logging.error("load api key cause error: e={}".format(e))
 
-    def _refresh(self, ep: str, resource_type: str = _DEFAULT_RESOURCE_TYPE):
+    def _refresh(self, ep: str, resource_type: str = _DEFAULT_RESOURCE_TYPE, project_name: str = None):
         if not self._need_refresh(ep, self._advisory_refresh_timeout):
             return
 
@@ -383,7 +408,7 @@ class StsTokenManager(object):
                 )
 
                 self._protected_refresh(
-                    ep, is_mandatory=is_mandatory_refresh, resource_type=resource_type
+                    ep, is_mandatory=is_mandatory_refresh, resource_type=resource_type, project_name=project_name
                 )
                 return
             finally:
@@ -394,11 +419,12 @@ class StsTokenManager(object):
                     return
 
                 self._protected_refresh(
-                    ep, is_mandatory=True, resource_type=resource_type
+                    ep, is_mandatory=True, resource_type=resource_type, project_name=project_name
                 )
 
-    def get(self, ep: str, resource_type: str = _DEFAULT_RESOURCE_TYPE) -> str:
-        self._refresh(ep, resource_type=resource_type)
+    def get(self, ep: str, resource_type: str = _DEFAULT_RESOURCE_TYPE, project_name: str = None) -> str:
+        self._refresh(ep, resource_type=resource_type,
+                      project_name=project_name)
         return self._endpoint_sts_tokens[ep][0]
 
     def _load_api_key(
@@ -406,12 +432,15 @@ class StsTokenManager(object):
         ep: str,
         duration_seconds: int,
         resource_type: str = _DEFAULT_RESOURCE_TYPE,
+        project_name: str = None,
     ) -> Tuple[str, int]:
         get_api_key_request = volcenginesdkark.GetApiKeyRequest(
             duration_seconds=duration_seconds,
             resource_type=resource_type,
             resource_ids=[ep],
         )
+        if project_name is not None and project_name.strip() != "":
+            get_api_key_request.project_name = project_name
         resp: volcenginesdkark.GetApiKeyResponse = self.api_instance.get_api_key(
             get_api_key_request
         )
@@ -436,9 +465,7 @@ class E2ECertificateManager(object):
         base_url: str | URL = BASE_URL,
         api_key: str | None = None,
     ):
-        self._certificate_manager: Dict[
-            str, Tuple[key_agreement_client, str, str, float]
-        ] = {}
+        self._certificate_manager: Dict[str, key_agreement_client] = {}
 
         # local cache prepare
         self._init_local_cert_cache()
@@ -484,7 +511,8 @@ class E2ECertificateManager(object):
         )
         if self._aicc_enabled:
             get_endpoint_certificate_request = (
-                volcenginesdkark.GetEndpointCertificateRequest(id=ep, type="AICCv0.1")
+                volcenginesdkark.GetEndpointCertificateRequest(
+                    id=ep, type="AICCv0.1")
             )
         try:
             resp: volcenginesdkark.GetEndpointCertificateResponse = (
@@ -500,7 +528,8 @@ class E2ECertificateManager(object):
         return resp.pca_instance_certificate
 
     def _sync_load_cert_by_auth(self, ep: str) -> str:
-        try:  # try to make request with session header (used for header statistic)
+        # try to make request with session header (used for header statistic)
+        try:
             req_body = {"model": ep}
             if self._aicc_enabled:
                 req_body["type"] = "AICCv0.1"
@@ -555,22 +584,18 @@ class E2ECertificateManager(object):
                     % (self._cert_storage_path, e)
                 )
 
-    def get(self, ep: str) -> Tuple[key_agreement_client, str, str, float]:
-        if ep not in self._certificate_manager:
-            cert_pem = self._load_cert_locally(ep)
-            if cert_pem is None:
-                if self.cert_path is not None:
-                    cert_pem = self._load_cert_by_cert_path()
-                elif self._ark_client_enabled:
-                    cert_pem = self._sync_load_cert_by_auth(ep)
-                else:
-                    cert_pem = self._load_cert_by_ak_sk(ep)
-                self._save_cert_to_file(ep, cert_pem)
-            ring, key, exp_time = get_cert_info(cert_pem)
-            self._certificate_manager[ep] = (
-                key_agreement_client(certificate_pem_string=cert_pem),
-                ring,
-                key,
-                exp_time,
-            )
-        return self._certificate_manager[ep]
+    def get(self, ep: str) -> key_agreement_client:
+        if ep in self._certificate_manager and not self._certificate_manager[ep].need_reload():
+            return self._certificate_manager[ep]
+        cert_pem = self._load_cert_locally(ep)
+        if cert_pem is None:
+            if self.cert_path is not None:
+                cert_pem = self._load_cert_by_cert_path()
+            elif self._ark_client_enabled:
+                cert_pem = self._sync_load_cert_by_auth(ep)
+            else:
+                cert_pem = self._load_cert_by_ak_sk(ep)
+            self._save_cert_to_file(ep, cert_pem)
+        client = key_agreement_client(certificate_pem_string=cert_pem)
+        self._certificate_manager[ep] = client
+        return client
