@@ -1,4 +1,3 @@
-
 # Copyright (c) [2025] [OpenAI]
 # Copyright (c) [2025] [ByteDance Ltd. and/or its affiliates.]
 # SPDX-License-Identifier: Apache-2.0
@@ -19,6 +18,7 @@ RAW_RESPONSE_HEADER = "X-Stainless-Raw-Response"
 CLIENT_REQUEST_HEADER = "X-Client-Request-Id"
 SERVER_REQUEST_HEADER = "X-Request-Id"
 ARK_E2E_ENCRYPTION_HEADER = "x-is-encrypted"
+ARK_APIKEY_PROJECT_NAME = "X-Project-Name"
 
 DEFAULT_TIMEOUT_SECONDS = 600.0
 DEFAULT_CONNECT_TIMEOUT_SECONDS = 60.0
@@ -40,3 +40,5 @@ _DEFAULT_ADVISORY_REFRESH_TIMEOUT = 30 * 60  # 30 min
 _DEFAULT_STS_TIMEOUT = 7 * 24 * 60 * 60  # 7 days
 
 _DEFAULT_RESOURCE_TYPE = "endpoint"
+_PRESETENDPOINT_RESOURCE_TYPE = "presetendpoint"
+_BOT_RESOURCE_TYPE = "bot"
